module.exports={A:{A:{"2":"J D E F A B nB"},B:{"1":"L G M N O","2":"C K","257":"P Q R U V W X Y Z a b c d e S f H"},C:{"1":"BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s pB qB","194":"0 1 2 3 4 5 6 7 8 9 t u v w x y z AB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 v w x y z AB BB CB DB EB FB GB","2":"I g J D E F A B C K L G M N O h i j k l m n o p q r s t u","257":"HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"1":"D E F A B C K L G wB xB kB cB dB yB zB 0B 1B","2":"I g J tB jB uB vB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB","2":"F B C G M N O h i j k l m n o 2B 3B 4B 5B cB lB 6B dB","257":"T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"1":"E AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC","2":"jB 7B mB 8B 9B"},H:{"2":"RC"},I:{"2":"eB I H SC TC UC VC mB WC XC"},J:{"2":"D A"},K:{"2":"A B C T cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"2":"YC"},P:{"1":"ZC aC bC cC dC kB eC fC gC hC iC","2":"I"},Q:{"1":"jC"},R:{"2":"kC"},S:{"1":"lC"}},B:7,C:"Speech Synthesis API"};
