module.exports={A:{A:{"2":"J D E F nB","129":"A B"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","129":"C K","1025":"L G M N O"},C:{"2":"oB eB I g J D E F A B C K L G M N O h i j k l m n o p q pB qB","513":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I g"},E:{"1":"g J D E F A B C K L G uB vB wB xB kB cB dB yB zB 0B 1B","2":"I tB jB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 F B C G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB 2B 3B 4B 5B cB lB 6B dB"},G:{"388":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"2":"eB SC TC UC","388":"I H VC mB WC XC"},J:{"2":"D","388":"A"},K:{"1":"A B C cB lB dB","388":"T"},L:{"388":"H"},M:{"641":"S"},N:{"388":"A B"},O:{"388":"YC"},P:{"388":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"388":"jC"},R:{"388":"kC"},S:{"513":"lC"}},B:1,C:"Number input type"};
