module.exports={A:{A:{"1":"B","2":"J D E F A nB"},B:{"2":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB","2":"oB eB I g J D E F A B C DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB pB qB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB","2":"DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"1":"E F A B C xB kB cB","2":"I g J D tB jB uB vB wB","129":"K L G dB yB zB 0B 1B"},F:{"1":"0 1 4 6 G M N O h i j k l m n o p q r s t u v w x y z dB","2":"2 3 5 7 8 9 F B C AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB 2B 3B 4B 5B cB lB 6B"},G:{"1":"E BC CC DC EC FC GC HC IC","2":"jB 7B mB 8B 9B AC","257":"JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"1":"eB I VC mB WC XC","2":"H SC TC UC"},J:{"2":"D A"},K:{"1":"dB","2":"A B C T cB lB"},L:{"2":"H"},M:{"2":"S"},N:{"1":"B","2":"A"},O:{"2":"YC"},P:{"1":"I","2":"ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"2":"jC"},R:{"16":"kC"},S:{"1":"lC"}},B:7,C:"SPDY protocol"};
