module.exports={A:{A:{"2":"J D E F A B nB"},B:{"2":"C K L G M N O","164":"P Q R U V W X Y Z a b c d e S f H"},C:{"1":"8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"0 1 2 3 4 5 6 oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z pB qB","322":"7"},D:{"2":"I g J D E F A B C K L G M N O h i j k l m","164":"0 1 2 3 4 5 6 7 8 9 n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"1":"E F A B C K L G wB xB kB cB dB yB zB 0B 1B","2":"I g J tB jB uB","164":"D vB"},F:{"2":"F B C 2B 3B 4B 5B cB lB 6B dB","164":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"1":"E AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC","2":"jB 7B mB 8B 9B"},H:{"2":"RC"},I:{"2":"eB I SC TC UC VC mB","164":"H WC XC"},J:{"2":"D","164":"A"},K:{"2":"A B C cB lB dB","164":"T"},L:{"164":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"164":"YC"},P:{"164":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"164":"jC"},R:{"164":"kC"},S:{"1":"lC"}},B:4,C:"text-emphasis styling"};
