module.exports={A:{A:{"2":"J D E F nB","132":"A B"},B:{"132":"C K L G M N O","1028":"P Q R U V W X Y Z a b c d e S f H"},C:{"2":"oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u pB qB","1028":"SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2564":"0 1 2 3 4 5 6 7 8 9 v w x y z AB","3076":"BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB"},D:{"16":"I g J D","132":"0 1 2 3 4 5 6 7 8 9 F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB","388":"E","1028":"gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"16":"I tB jB","132":"g J D E F A uB vB wB xB kB","1028":"B C K L G cB dB yB zB 0B 1B"},F:{"2":"F B C 2B 3B 4B 5B cB lB 6B dB","132":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z","1028":"AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"16":"jB 7B mB","132":"E 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"132":"I VC mB WC XC","292":"eB SC TC UC","1028":"H"},J:{"16":"D","132":"A"},K:{"2":"A B C cB lB dB","1028":"T"},L:{"1028":"H"},M:{"1028":"S"},N:{"132":"A B"},O:{"132":"YC"},P:{"132":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"132":"jC"},R:{"132":"kC"},S:{"2564":"lC"}},B:4,C:"DOMMatrix"};
