module.exports={A:{A:{"2":"J D E F nB","6308":"A","6436":"B"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","6436":"C K L G M N O"},C:{"1":"RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"0 oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z pB qB","2052":"1 2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB"},D:{"1":"SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB","8258":"PB QB RB"},E:{"1":"B C K L G cB dB yB zB 0B 1B","2":"I g J D E tB jB uB vB wB","3108":"F A xB kB"},F:{"1":"T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"0 1 2 3 4 5 6 7 8 9 F B C G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB 2B 3B 4B 5B cB lB 6B dB","8258":"GB HB IB JB KB LB MB NB"},G:{"1":"GC HC IC JC KC LC MC NC OC PC QC","2":"E jB 7B mB 8B 9B AC BC","3108":"CC DC EC FC"},H:{"2":"RC"},I:{"1":"H","2":"eB I SC TC UC VC mB WC XC"},J:{"2":"D A"},K:{"1":"T","2":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"2":"YC"},P:{"1":"kB eC fC gC hC iC","2":"I ZC aC bC cC dC"},Q:{"2":"jC"},R:{"2":"kC"},S:{"2052":"lC"}},B:4,C:"CSS Scroll Snap"};
