module.exports={A:{A:{"2":"J D E F A B nB"},B:{"1":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","33":"oB eB I g J D E F A B C K L G M N O h i j k l pB qB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","33":"I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y"},E:{"1":"F A B C K L G xB kB cB dB yB zB 0B 1B","33":"I g J D E tB jB uB vB wB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 C m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB 6B dB","2":"F B 2B 3B 4B 5B cB lB","33":"G M N O h i j k l"},G:{"2":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"1":"H","2":"eB I SC TC UC VC mB WC XC"},J:{"33":"D A"},K:{"1":"T","2":"A B C cB lB dB"},L:{"1":"H"},M:{"2":"S"},N:{"2":"A B"},O:{"2":"YC"},P:{"2":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"2":"jC"},R:{"2":"kC"},S:{"2":"lC"}},B:4,C:"CSS3 Cursors: zoom-in & zoom-out"};
