"use strict";

exports.__esModule = true;
exports.default = void 0;

// This file is automatically generated by scripts/build-corejs3-shipped-proposals.js
var _default = new Set([]);

exports.default = _default;