module.exports={A:{A:{"2436":"J D E F A B nB"},B:{"260":"N O","2436":"C K L G M","8196":"P Q R U V W X Y Z a b c d e S f H"},C:{"2":"oB eB I g J D E F A B C K L G M N O h i j pB qB","772":"0 1 2 k l m n o p q r s t u v w x y z","4100":"3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB"},D:{"2":"I g J D E F A B C","2564":"0 1 2 3 4 K L G M N O h i j k l m n o p q r s t u v w x y z","8196":"KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","10244":"5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB"},E:{"1":"C K L G dB yB zB 0B 1B","16":"tB jB","2308":"A B kB cB","2820":"I g J D E F uB vB wB xB"},F:{"2":"F B 2B 3B 4B 5B cB lB 6B","16":"C","516":"dB","2564":"G M N O h i j k l m n o p q r","8196":"7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","10244":"0 1 2 3 4 5 6 s t u v w x y z"},G:{"1":"IC JC KC LC MC NC OC PC QC","2":"jB 7B mB","2820":"E 8B 9B AC BC CC DC EC FC GC HC"},H:{"2":"RC"},I:{"2":"eB I SC TC UC VC mB","260":"H","2308":"WC XC"},J:{"2":"D","2308":"A"},K:{"2":"A B C cB lB","16":"dB","260":"T"},L:{"8196":"H"},M:{"1028":"S"},N:{"2":"A B"},O:{"2":"YC"},P:{"2052":"ZC aC","2308":"I","8196":"bC cC dC kB eC fC gC hC iC"},Q:{"10244":"jC"},R:{"2052":"kC"},S:{"4100":"lC"}},B:5,C:"Synchronous Clipboard API"};
