module.exports={A:{A:{"1":"F A B","16":"nB","132":"J D E"},B:{"1":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB pB qB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","132":"I g J D E F A B C K L G M N O h i j k l m n o p q r"},E:{"1":"D E F A B C K L G vB wB xB kB cB dB yB zB 0B 1B","16":"tB","132":"I g J jB uB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","16":"F 2B","132":"B C G M 3B 4B 5B cB lB 6B dB"},G:{"1":"E 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC","16":"jB"},H:{"2":"RC"},I:{"1":"H WC XC","16":"SC TC","132":"eB I UC VC mB"},J:{"132":"D A"},K:{"1":"T","132":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"A B"},O:{"1":"YC"},P:{"1":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1":"jC"},R:{"1":"kC"},S:{"1":"lC"}},B:2,C:"letter-spacing CSS property"};
