module.exports={A:{A:{"2":"J D E nB","260":"F A B"},B:{"1":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB I g J D E F A B C K L pB qB"},D:{"1":"CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x","132":"0 1 2 3 4 5 6 7 8 9 y z AB BB"},E:{"1":"C K L G cB dB yB zB 0B 1B","2":"I g J D F A B tB jB uB vB xB kB","132":"E wB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB dB","2":"G M N O h i j k","4":"B C 3B 4B 5B cB lB 6B","16":"F 2B","132":"l m n o p q r s t u v w x y"},G:{"1":"HC IC JC KC LC MC NC OC PC QC","2":"jB 7B mB 8B 9B AC CC DC EC FC GC","132":"E BC"},H:{"1":"RC"},I:{"1":"H","2":"eB I SC TC UC VC mB WC XC"},J:{"2":"D","132":"A"},K:{"1":"T dB","4":"A B C cB lB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"A B"},O:{"1":"YC"},P:{"1":"ZC aC bC cC dC kB eC fC gC hC iC","132":"I"},Q:{"1":"jC"},R:{"132":"kC"},S:{"1":"lC"}},B:4,C:"SVG fragment identifiers"};
