module.exports={A:{A:{"2":"J D E nB","4":"F A B"},B:{"1":"N O P Q R U V W X Y Z a b c d e S f H","4":"C K L G M"},C:{"1":"6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x pB qB","194":"0 1 2 3 4 5 y z"},D:{"1":"0 1 2 3 4 5 6 7 8 9 y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","4":"I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x"},E:{"1":"A B C K L G kB cB dB yB zB 0B 1B","4":"I g J D E F tB jB uB vB wB xB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"F B C 2B 3B 4B 5B cB lB 6B dB","4":"G M N O h i j k"},G:{"1":"EC FC GC HC IC JC KC LC MC NC OC PC QC","4":"E jB 7B mB 8B 9B AC BC CC DC"},H:{"2":"RC"},I:{"1":"H","4":"eB I SC TC UC VC mB WC XC"},J:{"2":"D","4":"A"},K:{"1":"T","2":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"4":"A B"},O:{"1":"YC"},P:{"1":"ZC aC bC cC dC kB eC fC gC hC iC","4":"I"},Q:{"1":"jC"},R:{"2":"kC"},S:{"1":"lC"}},B:4,C:"Font unicode-range subsetting"};
