module.exports={A:{A:{"2":"J D E F A B nB"},B:{"1":"N O P Q R U V W X Y Z a b c d e S f H","2":"C K L G M"},C:{"2":"0 1 2 3 4 5 6 7 8 9 oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB pB qB","4609":"MB NB T OB PB QB RB SB TB","4674":"gB","5698":"LB","7490":"FB GB HB IB JB","7746":"KB fB","8705":"UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB"},D:{"1":"QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB","4097":"PB","4290":"fB LB gB","6148":"MB NB T OB"},E:{"1":"G 0B 1B","2":"I g J D E F A tB jB uB vB wB xB kB","4609":"B C cB dB","8193":"K L yB zB"},F:{"1":"GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"0 1 2 3 4 5 6 7 8 9 F B C G M N O h i j k l m n o p q r s t u v w x y z AB 2B 3B 4B 5B cB lB 6B dB","4097":"FB","6148":"BB CB DB EB"},G:{"1":"KC LC MC NC OC PC QC","2":"E jB 7B mB 8B 9B AC BC CC DC EC FC","4097":"GC HC IC JC"},H:{"2":"RC"},I:{"1":"H","2":"eB I SC TC UC VC mB WC XC"},J:{"2":"D A"},K:{"1":"T","2":"A B C cB lB dB"},L:{"1":"H"},M:{"4097":"S"},N:{"2":"A B"},O:{"2":"YC"},P:{"2":"I ZC aC bC","4097":"cC dC kB eC fC gC hC iC"},Q:{"4097":"jC"},R:{"2":"kC"},S:{"2":"lC"}},B:5,C:"Variable fonts"};
