module.exports={A:{A:{"2":"J D E F A nB","132":"B"},B:{"1":"C K L G M N O","513":"P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 y z AB BB CB DB EB","2":"oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x pB qB","513":"FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB"},D:{"1":"3 4 5 6 7 8 9 AB BB CB","2":"0 1 2 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z","513":"DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"1":"B C K L G cB dB yB zB 0B 1B","2":"I g J D E tB jB uB vB wB","260":"F A xB kB"},F:{"1":"q r s t u v w x y z","2":"F B C G M N O h i j k l m n o p 2B 3B 4B 5B cB lB 6B dB","513":"0 1 2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"1":"CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC","2":"E jB 7B mB 8B 9B AC BC"},H:{"2":"RC"},I:{"2":"eB I SC TC UC VC mB WC XC","513":"H"},J:{"2":"D A"},K:{"2":"A B C cB lB dB","513":"T"},L:{"513":"H"},M:{"513":"S"},N:{"2":"A B"},O:{"1":"YC"},P:{"1":"I","513":"ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"513":"jC"},R:{"1":"kC"},S:{"1":"lC"}},B:6,C:"HTTP/2 protocol"};
