module.exports={A:{A:{"2":"J nB","2340":"D E F A B"},B:{"2":"C K L G M N O","1025":"P Q R U V W X Y Z a b c d e S f H"},C:{"1":"e S f H iB","2":"oB eB pB","513":"OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d","545":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T qB"},D:{"2":"0 1 2 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z","1025":"3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"1":"A B C K L G kB cB dB yB zB 0B 1B","2":"I g tB jB uB","164":"J","4644":"D E F vB wB xB"},F:{"2":"F B G M N O h i j k l m n o p 2B 3B 4B 5B cB lB","545":"C 6B dB","1025":"0 1 2 3 4 5 6 7 8 9 q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"1":"EC FC GC HC IC JC KC LC MC NC OC PC QC","2":"jB 7B mB","4260":"8B 9B","4644":"E AC BC CC DC"},H:{"2":"RC"},I:{"2":"eB I SC TC UC VC mB WC XC","1025":"H"},J:{"2":"D","4260":"A"},K:{"2":"A B cB lB","545":"C dB","1025":"T"},L:{"1025":"H"},M:{"545":"S"},N:{"2340":"A B"},O:{"1":"YC"},P:{"1025":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1025":"jC"},R:{"1025":"kC"},S:{"4097":"lC"}},B:7,C:"Crisp edges/pixelated images"};
