module.exports={A:{A:{"2":"J D E F A B nB"},B:{"2":"C K L G M N","260":"P Q R U V W X Y Z a b c d e S f H","3138":"O"},C:{"1":"GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB","132":"0 1 2 3 4 5 6 7 8 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z pB qB","644":"9 AB BB CB DB EB FB"},D:{"2":"I g J D E F A B C K L G M N O h i j k l","260":"HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","292":"0 1 2 3 4 5 6 7 8 9 m n o p q r s t u v w x y z AB BB CB DB EB FB GB"},E:{"2":"I g J tB jB uB vB","292":"D E F A B C K L G wB xB kB cB dB yB zB 0B 1B"},F:{"2":"F B C 2B 3B 4B 5B cB lB 6B dB","260":"4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","292":"0 1 2 3 G M N O h i j k l m n o p q r s t u v w x y z"},G:{"2":"jB 7B mB 8B 9B","292":"E AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"2":"eB I SC TC UC VC mB","260":"H","292":"WC XC"},J:{"2":"D A"},K:{"2":"A B C cB lB dB","260":"T"},L:{"260":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"292":"YC"},P:{"292":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"292":"jC"},R:{"260":"kC"},S:{"644":"lC"}},B:4,C:"CSS clip-path property (for HTML)"};
