module.exports={A:{A:{"2":"J D E nB","8":"F","292":"A B"},B:{"1":"M N O P Q R U V W X Y Z a b c d e S f H","292":"C K L G"},C:{"1":"GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB I g J D E F A B C K L G M N O pB qB","8":"0 1 h i j k l m n o p q r s t u v w x y z","584":"2 3 4 5 6 7 8 9 AB BB CB DB","1025":"EB FB"},D:{"1":"KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I g J D E F A B C K L G M N O h i j k l m","8":"n o p q","200":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z AB BB CB DB EB FB GB HB IB","1025":"JB"},E:{"1":"B C K L G kB cB dB yB zB 0B 1B","2":"I g tB jB uB","8":"J D E F A vB wB xB"},F:{"1":"6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"F B C G M N O h i j k l m n o p 2B 3B 4B 5B cB lB 6B dB","200":"0 1 2 3 4 5 q r s t u v w x y z"},G:{"1":"FC GC HC IC JC KC LC MC NC OC PC QC","2":"jB 7B mB 8B","8":"E 9B AC BC CC DC EC"},H:{"2":"RC"},I:{"1":"H","2":"eB I SC TC UC VC","8":"mB WC XC"},J:{"2":"D A"},K:{"1":"T","2":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"292":"A B"},O:{"1":"YC"},P:{"1":"aC bC cC dC kB eC fC gC hC iC","2":"ZC","8":"I"},Q:{"1":"jC"},R:{"2":"kC"},S:{"1":"lC"}},B:4,C:"CSS Grid Layout (level 1)"};
