module.exports={A:{A:{"1":"B","2":"J D E F nB","164":"A"},B:{"1":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB I g pB qB","8":"0 1 2 J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z","328":"3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB"},D:{"1":"HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I g J D E F A B C K L G M N O h i j","8":"0 1 2 3 4 5 6 7 8 9 k l m n o p q r s t u v w x y z AB BB CB DB","584":"EB FB GB"},E:{"1":"K L G yB zB 0B 1B","2":"I g J tB jB uB","8":"D E F A B C vB wB xB kB cB","1096":"dB"},F:{"1":"4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"F B C 2B 3B 4B 5B cB lB 6B dB","8":"0 G M N O h i j k l m n o p q r s t u v w x y z","584":"1 2 3"},G:{"1":"LC MC NC OC PC QC","8":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC","6148":"KC"},H:{"2":"RC"},I:{"1":"H","8":"eB I SC TC UC VC mB WC XC"},J:{"8":"D A"},K:{"1":"T","2":"A","8":"B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"B","36":"A"},O:{"8":"YC"},P:{"1":"aC bC cC dC kB eC fC gC hC iC","2":"ZC","8":"I"},Q:{"1":"jC"},R:{"2":"kC"},S:{"328":"lC"}},B:2,C:"Pointer events"};
