module.exports={A:{A:{"1":"A B","2":"J D E F nB"},B:{"1":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB I pB qB","33":"g J D E F A B C K L G"},D:{"1":"5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","33":"0 1 2 3 4 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z"},E:{"1":"F A B C K L G xB kB cB dB yB zB 0B 1B","2":"tB jB","33":"J D E uB vB wB","292":"I g"},F:{"1":"0 1 2 3 4 5 6 7 8 9 s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB dB","2":"F B 2B 3B 4B 5B cB lB 6B","33":"C G M N O h i j k l m n o p q r"},G:{"1":"CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC","33":"E 9B AC BC","164":"jB 7B mB 8B"},H:{"2":"RC"},I:{"1":"H","33":"I VC mB WC XC","164":"eB SC TC UC"},J:{"33":"D A"},K:{"1":"T dB","2":"A B C cB lB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"A B"},O:{"1":"YC"},P:{"1":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"33":"jC"},R:{"1":"kC"},S:{"1":"lC"}},B:5,C:"CSS Animation"};
