module.exports={A:{A:{"1":"A B","2":"J D E F nB"},B:{"1":"C K L G M N O","516":"P Q R U V W X Y Z a b c d e S f H"},C:{"132":"EB FB GB HB IB JB KB fB LB gB MB NB T","164":"0 1 2 3 4 5 6 7 8 9 oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB pB qB","516":"OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c","1028":"d e S f H iB"},D:{"420":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB","516":"CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"1":"A B C K L G kB cB dB yB zB 0B 1B","132":"F xB","164":"D E wB","420":"I g J tB jB uB vB"},F:{"1":"C cB lB 6B dB","2":"F B 2B 3B 4B 5B","420":"G M N O h i j k l m n o p q r s t u v w x y","516":"0 1 2 3 4 5 6 7 8 9 z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"1":"EC FC GC HC IC JC KC LC MC NC OC PC QC","132":"CC DC","164":"E AC BC","420":"jB 7B mB 8B 9B"},H:{"1":"RC"},I:{"420":"eB I SC TC UC VC mB WC XC","516":"H"},J:{"420":"D A"},K:{"1":"C cB lB dB","2":"A B","516":"T"},L:{"516":"H"},M:{"516":"S"},N:{"1":"A B"},O:{"1":"YC"},P:{"1":"ZC aC bC cC dC kB eC fC gC hC iC","420":"I"},Q:{"132":"jC"},R:{"132":"kC"},S:{"164":"lC"}},B:4,C:"CSS3 Multiple column layout"};
