module.exports={A:{A:{"2":"F A B nB","8":"J D E"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","2":"C K L G M N O"},C:{"1":"BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB","8":"0 1 2 3 4 5 6 7 8 eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z pB qB","194":"9 AB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","8":"I g J D E F A B","257":"h i j k l m n o p q r s t u v w x","769":"C K L G M N O"},E:{"1":"C K L G dB yB zB 0B 1B","8":"I g tB jB uB","257":"J D E F A vB wB xB","1025":"B kB cB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"C cB lB 6B dB","8":"F B 2B 3B 4B 5B"},G:{"1":"E 9B AC BC CC DC HC IC JC KC LC MC NC OC PC QC","8":"jB 7B mB 8B","1025":"EC FC GC"},H:{"8":"RC"},I:{"1":"I H VC mB WC XC","8":"eB SC TC UC"},J:{"1":"A","8":"D"},K:{"1":"T","8":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"769":"YC"},P:{"1":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1":"jC"},R:{"1":"kC"},S:{"1":"lC"}},B:1,C:"Details & Summary elements"};
