module.exports={A:{A:{"2":"J D E F nB","8":"A B"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","8":"C K L G M N O"},C:{"1":"NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r pB qB","8":"0 1 2 3 4 5 6 7 8 9 s t u v w x y z AB BB","456":"CB DB EB FB GB HB IB JB KB","712":"fB LB gB MB"},D:{"1":"QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB","8":"EB FB","132":"GB HB IB JB KB fB LB gB MB NB T OB PB"},E:{"2":"I g J D tB jB uB vB wB","8":"E F A xB","132":"B C K L G kB cB dB yB zB 0B 1B"},F:{"1":"T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"0 1 2 F B C G M N O h i j k l m n o p q r s t u v w x y z 2B 3B 4B 5B cB lB 6B dB","132":"3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB NB"},G:{"2":"E jB 7B mB 8B 9B AC BC CC DC EC","132":"FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"1":"H","2":"eB I SC TC UC VC mB WC XC"},J:{"2":"D A"},K:{"1":"T","2":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"1":"YC"},P:{"1":"aC bC cC dC kB eC fC gC hC iC","2":"I","132":"ZC"},Q:{"132":"jC"},R:{"132":"kC"},S:{"8":"lC"}},B:1,C:"Custom Elements (V1)"};
