module.exports={A:{A:{"1":"A B","2":"J D E F nB"},B:{"1":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB qB","2":"oB eB pB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I"},E:{"1":"I g J D E F A B C K L G uB vB wB xB kB cB dB yB zB 0B 1B","2":"tB jB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 B C G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB 5B cB lB 6B dB","2":"F 2B 3B 4B"},G:{"1":"E 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC","2":"jB 7B mB 8B"},H:{"130":"RC"},I:{"130":"eB I H SC TC UC VC mB WC XC"},J:{"2":"D A"},K:{"130":"A B C T cB lB dB"},L:{"132":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"130":"YC"},P:{"130":"I","132":"ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"132":"jC"},R:{"132":"kC"},S:{"2":"lC"}},B:1,C:"Multiple file selection"};
