module.exports={A:{A:{"644":"J D E F nB","772":"A B"},B:{"1":"O P Q R U V W X Y Z a b c d e S f H","260":"C K L G M N"},C:{"1":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB pB qB","8":"oB eB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"1":"I g J D E F A B C K L G tB jB uB vB wB xB kB cB dB yB zB 0B 1B"},F:{"1":"0 1 2 3 4 5 6 7 8 9 C G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB dB","8":"F B 2B 3B 4B 5B cB lB 6B"},G:{"1":"QC","2":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC"},H:{"2":"RC"},I:{"2":"eB I SC TC UC VC mB WC XC","1025":"H"},J:{"2":"D A"},K:{"1":"dB","8":"A B C cB lB","1025":"T"},L:{"1025":"H"},M:{"2":"S"},N:{"1":"A B"},O:{"2":"YC"},P:{"2":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1":"jC"},R:{"2":"kC"},S:{"2":"lC"}},B:1,C:"Drag and Drop"};
