module.exports={A:{A:{"2":"J D E F A B nB"},B:{"2":"C K L G M N O","1537":"P Q R U V W X Y Z a b c d e S f H"},C:{"2":"oB","932":"0 1 2 3 4 5 6 7 8 9 eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB pB qB","2308":"PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB"},D:{"2":"I g J D E F A B C K L G M N O h i j","545":"0 1 2 3 4 5 6 7 k l m n o p q r s t u v w x y z","1537":"8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"2":"I g J tB jB uB","516":"B C K L G cB dB yB zB 0B 1B","548":"F A xB kB","676":"D E vB wB"},F:{"2":"F B C 2B 3B 4B 5B cB lB 6B dB","513":"w","545":"G M N O h i j k l m n o p q r s t u","1537":"0 1 2 3 4 5 6 7 8 9 v x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"2":"jB 7B mB 8B 9B","516":"OC PC QC","548":"CC DC EC FC GC HC IC JC KC LC MC NC","676":"E AC BC"},H:{"2":"RC"},I:{"2":"eB I SC TC UC VC mB","545":"WC XC","1537":"H"},J:{"2":"D","545":"A"},K:{"2":"A B C cB lB dB","1537":"T"},L:{"1537":"H"},M:{"2308":"S"},N:{"2":"A B"},O:{"1":"YC"},P:{"545":"I","1537":"ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"545":"jC"},R:{"1537":"kC"},S:{"932":"lC"}},B:5,C:"Intrinsic & Extrinsic Sizing"};
