module.exports={A:{A:{"1":"A B","16":"nB","900":"J D E F"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","1025":"C K L G M N O"},C:{"1":"DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","900":"oB eB pB qB","1025":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"1":"J D E F A B C K L G uB vB wB xB kB cB dB yB zB 0B 1B","16":"g tB","900":"I jB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","16":"F","132":"B C 2B 3B 4B 5B cB lB 6B dB"},G:{"1":"7B mB 8B 9B AC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC","16":"jB","2052":"E BC"},H:{"132":"RC"},I:{"1":"eB I UC VC mB WC XC","16":"SC TC","4097":"H"},J:{"1":"D A"},K:{"132":"A B C cB lB dB","4097":"T"},L:{"4097":"H"},M:{"4097":"S"},N:{"1":"A B"},O:{"1":"YC"},P:{"4097":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1":"jC"},R:{"1":"kC"},S:{"1025":"lC"}},B:1,C:"maxlength attribute for input and textarea elements"};
